/***************************************************************************
 *   Copyright (C) 2004 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "configlogoptions.h"
#include <kcolordialog.h>
#include <QtGui/qcheckbox.h>
#include <QtGui/qlabel.h>
#include <Qt3Support/q3groupbox.h>
#include <kpushbutton.h>
#include "configlogoptions.moc"

#include <iostream>

ConfigLogOptions::ConfigLogOptions(QWidget *parent)
{
	main = new Ui_ConfigLogOptionsBase();
	main->setupUi(this);
	connect(main->DebugLogFontPushButton, SIGNAL(clicked(bool)), this, SLOT(debugLogColorClicked(bool)));
	connect(main->ErrorLogFontPushButton, SIGNAL(clicked(bool)), this, SLOT(errorLogColorClicked(bool)));
	connect(main->InfoLogFontPushButton, SIGNAL(clicked(bool)), this, SLOT(infoLogColorClicked(bool)));
	connect(main->RemoteLogFontPushButton, SIGNAL(clicked(bool)), this, SLOT(remoteLogColorClicked(bool)));
	connect(main->SuccessLogFontPushButton, SIGNAL(clicked(bool)), this, SLOT(successLogColorClicked(bool)));
	connect(main->UseColorizedLogOutputcheckBox, SIGNAL(stateChanged(int)), this, SLOT(useColorizedLogOutputToggled(int)));
	connect(main->BackgroundLogFontPushButton, SIGNAL(clicked(bool)), this, SLOT(backgroundLogColorClicked(bool)));

	main->ErrorLogLabel->setAutoFillBackground( true );
	main->DebugLogLabel->setAutoFillBackground( true );
	main->InfoLogLabel->setAutoFillBackground( true );
	main->RemoteLogLabel->setAutoFillBackground( true );
	main->SuccessLogLabel->setAutoFillBackground( true );
	main->SuccessLogLabel->setAutoFillBackground( true );
}


ConfigLogOptions::~ConfigLogOptions()
{}

void ConfigLogOptions::errorLogColorClicked(bool)
{

	int result = KColorDialog::getColor( ErrorLogColor );
	if ( result == KColorDialog::Accepted )
		main->ErrorLogLabel->setPaletteBackgroundColor (ErrorLogColor);
}

void ConfigLogOptions::debugLogColorClicked(bool)
{
	int result = KColorDialog::getColor( DebugLogColor );
	if ( result == KColorDialog::Accepted )
		main->DebugLogLabel->setPaletteBackgroundColor (DebugLogColor);
}

void ConfigLogOptions::infoLogColorClicked(bool)
{
	int result = KColorDialog::getColor( InfoLogColor );
	if ( result == KColorDialog::Accepted )
		main->InfoLogLabel->setPaletteBackgroundColor (InfoLogColor);
}

void ConfigLogOptions::remoteLogColorClicked(bool)
{
	int result = KColorDialog::getColor( RemoteLogColor );
	if ( result == KColorDialog::Accepted )
		main->RemoteLogLabel->setPaletteBackgroundColor (RemoteLogColor);
}

void ConfigLogOptions::successLogColorClicked(bool)
{
	int result = KColorDialog::getColor( SuccessLogColor );
	if ( result == KColorDialog::Accepted )
		main->SuccessLogLabel->setPaletteBackgroundColor (SuccessLogColor);
}

void ConfigLogOptions::useColorizedLogOutputToggled(int)
{
	if (main->UseColorizedLogOutputcheckBox->isChecked() )
		main->ColorGroupBox->setEnabled(true);
	else
		main->ColorGroupBox->setEnabled(false);
}

void ConfigLogOptions::backgroundLogColorClicked(bool)
{
	int result = KColorDialog::getColor( BackgroundLogColor );
	if ( result == KColorDialog::Accepted )
		main->BackgroundLogLabel->setPaletteBackgroundColor(BackgroundLogColor);
}

void ConfigLogOptions::dialogChanged()
{
// 	std::cout << "ConfigLogOptions::dialogChanged()" << std::endl;
	dialogModified=true;
}

